// Copyright (c) 2023 Tudor Stanciu

import { useContext, useCallback, useState, useEffect } from "react";
import { TuitioContext } from "../contexts";
import { camelizeKeys } from "@flare/js-utils";
import type { TuitioTokenData } from "@flare/tuitio-client";

const useTuitioToken = () => {
  const state = useContext(TuitioContext);
  const [decodedToken, setDecodedToken] = useState<TuitioTokenData>();

  const validate = useCallback((): boolean => {
    const validUntil = state.auth.validUntil;
    if (!validUntil) {
      return false;
    }
    const valid = new Date(validUntil) >= new Date();
    return valid;
  }, [state.auth.validUntil]);

  useEffect(() => {
    if (decodedToken || !state.auth.token) return;
    const decodedTokenBuffer = Buffer.from(state.auth.token, "base64");
    const decodedTokenString = decodedTokenBuffer.toString("utf-8");
    const decoded = camelizeKeys(JSON.parse(decodedTokenString));
    setDecodedToken(decoded);
  }, [decodedToken, state.auth.token]);

  const token = state.auth.token;
  const valid: boolean = validate();

  return { token, validate, valid, decodedToken };
};

export { useTuitioToken };
